==> bootstrap-7.0.0-rc.45.tgz: package/tsDist/components/dashboard/shared/Welcome/SessionsButton.js <==
import styled from 'styled-components';
import color from 'color';
import { Box } from 'components/elements';
import { isIeBrowser } from '../../utils';
var addOpacityToRgbColor = function (rgbColor, opacity) {
    var fadedColor = color(rgbColor).fade(opacity);
    var hslColor = fadedColor.hsl();
    return hslColor.round().toString();
};
export var SessionsButton = styled.div({
    minWidth: '50%',
    flexGrow: 1,
    borderRadius: '0',
    position: 'relative',
    padding: '24px',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
}, function (_a) {
    var _b;
    var theme = _a.theme, btnType = _a.btnType, text = _a.text;
    var btnBackgroundColor = 'transparent';
    var color = btnType === 'primary' ? 'default' : 'hover';
    if (isIeBrowser()) {
        btnBackgroundColor = addOpacityToRgbColor(theme.colors.secondary.dark, 0.5);
    }
    return _b = {
            backgroundColor: theme.colors.secondary[color],
            '&:active:hover': {
                backgroundColor: theme.colors.secondary.dark,
            },
            '&:hover, &:focus': {
                backgroundColor: theme.colors.secondary.dark,
                overflow: 'hidden',
            }
        },
        // '&:hover:after': {
        //   content: `'${text}'`,
        //   display: 'block',
        //   fontSize: '14px',
        //   position: 'absolute',
        //   top: '50%',
        //   right: '50%',
        //   border: '1px solid white',
        //   transform: 'translate(50%, -50%)',
        //   padding: '4px 12px',
        //   minWidth: '135px',
        //   borderRadius: '25px',
        //   whiteSpace: 'nowrap',
        //   backgroundColor: btnBackgroundColor,
        // },
        _b["& > " + Box] = {
            transition: "0.2s filter, 0.2s opacity",
        },
        _b["&:hover > " + Box] = {
            filter: "blur(4px)",
            opacity: 0.75,
        },
        _b;
});

==> bootstrap-7.0.15.tgz: package/tsDist/components/dashboard/shared/Welcome/SessionsButton.js <==
import styled from 'styled-components';
import color from 'color';
import { Box } from 'components/elements';
import { Button } from 'components/inputs';
import { isIeBrowser } from '../../utils';
var addOpacityToRgbColor = function (rgbColor, opacity) {
    var fadedColor = color(rgbColor).fade(opacity);
    var hslColor = fadedColor.hsl();
    return hslColor.round().toString();
};
export var SessionsButton = styled(Button)({
    minWidth: '50%',
    flexGrow: 1,
    borderRadius: '0',
    position: 'relative',
    padding: '24px',
}, function (_a) {
    var _b;
    var theme = _a.theme, btnType = _a.btnType, text = _a.text;
    var btnBackgroundColor = 'transparent';
    var color = btnType === 'primary' ? 'default' : 'hover';
    if (isIeBrowser()) {
        btnBackgroundColor = addOpacityToRgbColor(theme.colors.secondary.dark, 0.5);
    }
    return _b = {
            backgroundColor: theme.colors.secondary[color],
            '&:active:hover': {
                backgroundColor: theme.colors.secondary.dark,
            },
            '&:hover, &:focus': {
                backgroundColor: theme.colors.secondary.dark,
                overflow: 'hidden',
            },
            '&:hover:after': {
                content: "'" + text + "'",
                display: 'block',
                fontSize: '14px',
                position: 'absolute',
                top: '50%',
                right: '50%',
                border: '1px solid white',
                transform: 'translate(50%, -50%)',
                padding: '4px 12px',
                minWidth: '135px',
                borderRadius: '25px',
                whiteSpace: 'nowrap',
                backgroundColor: btnBackgroundColor,
            }
        },
        _b["& > " + Box] = {
            transition: "0.2s filter, 0.2s opacity",
        },
        _b["&:hover > " + Box] = {
            filter: "blur(4px)",
            opacity: 0.75,
        },
        _b;
});
